@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2012  Patrick Totzke <patricktotzke@gmail.com>
+# Copyright (C) Patrick Totzke <patricktotzke@gmail.com>
 # Copyright © 2018 Dylan Baker
 # This file is released under the GNU GPL, version 3 or a later revision.
 # For further details see the COPYING file
@@ -6,6 +6,7 @@ import argparse
 import datetime
 import email
 import email.policy
+import fnmatch
 import glob
 import logging
 import os
@@ -13,6 +14,7 @@ import re
 import tempfile
 import textwrap
 import traceback
+import sys
 
 from . import Command, registerCommand
 from . import globals
@@ -37,7 +39,7 @@ MODE = 'envelope'
 
 @registerCommand(
     MODE, 'attach',
-    arguments=[(['path'], {'help': 'file(s) to attach (accepts wildcads)'})])
+    arguments=[(['path'], {'help': 'file(s) to attach (accepts wildcards)'})])
 class AttachCommand(Command):
     """attach files to the mail"""
     repeatable = True
@@ -65,30 +67,30 @@ class AttachCommand(Command):
         ui.current_buffer.rebuild()
 
 
-@registerCommand(MODE, 'unattach', arguments=[
-    (['hint'], {'nargs': '?', 'help': 'which attached file to remove'}),
+@registerCommand(MODE, 'detach', arguments=[
+    (['files'], {
+        'nargs': '?',
+        'help': 'name of the attachment to remove (accepts wildcards)'
+    }),
 ])
-class UnattachCommand(Command):
+class DetachCommand(Command):
     """remove attachments from current envelope"""
     repeatable = True
 
-    def __init__(self, hint=None, **kwargs):
+    def __init__(self, files=None, **kwargs):
         """
-        :param hint: which attached file to remove
-        :type hint: str
+        :param files: attached file glob to remove
+        :type files: str
         """
         Command.__init__(self, **kwargs)
-        self.hint = hint
+        self.files = files or '*'
 
     def apply(self, ui):
         envelope = ui.current_buffer.envelope
-
-        if self.hint is not None:
-            for a in envelope.attachments:
-                if self.hint in a.get_filename():
-                    envelope.attachments.remove(a)
-        else:
-            envelope.attachments = []
+        envelope.attachments = [
+            attachment for attachment in envelope.attachments
+            if not fnmatch.fnmatch(attachment.get_filename(), self.files)
+        ]
         ui.current_buffer.rebuild()
 
 
@@ -134,7 +136,7 @@ class SaveCommand(Command):
         mail = envelope.construct_mail()
         # store mail locally
         path = account.store_draft_mail(
-            mail.as_string(policy=email.policy.SMTP))
+            mail.as_string(policy=email.policy.SMTP, maxheaderlen=sys.maxsize))
 
         msg = 'draft saved successfully'
 
@@ -242,7 +244,8 @@ class SendCommand(Command):
 
             try:
                 self.mail = self.envelope.construct_mail()
-                self.mail = self.mail.as_string(policy=email.policy.SMTP)
+                self.mail = self.mail.as_string(policy=email.policy.SMTP,
+                                                maxheaderlen=sys.maxsize)
             except GPGProblem as e:
                 ui.clear_notify([clearme])
                 ui.notify(str(e), priority='error')
@@ -759,13 +762,13 @@ class BodyConvertCommand(Command):
         ebuffer = ui.current_buffer
         envelope = ebuffer.envelope
 
-        if self.action is "txt2html":
+        if self.action == "txt2html":
             fallbackcmd = settings.get('envelope_txt2html')
             cmd = self.cmd or split_commandstring(fallbackcmd)
             if cmd:
                 envelope.body_html = self.convert(cmd, envelope.body_txt)
 
-        elif self.action is "html2txt":
+        elif self.action == "html2txt":
             fallbackcmd = settings.get('envelope_html2txt')
             cmd = self.cmd or split_commandstring(fallbackcmd)
             if cmd:
