@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2012  Patrick Totzke <patricktotzke@gmail.com>
+# Copyright (C) Patrick Totzke <patricktotzke@gmail.com>
 # Copyright © 2018 Dylan Baker
 # This file is released under the GNU GPL, version 3 or a later revision.
 # For further details see the COPYING file
@@ -73,15 +73,19 @@ class ExitCommand(Command):
 
         for b in ui.buffers:
             b.cleanup()
-        await ui.apply_command(FlushCommand(callback=ui.exit))
-        ui.cleanup()
 
         if ui.db_was_locked:
             msg = 'Database locked. Exit without saving?'
             response = await ui.choice(msg, msg_position='left', cancel='no')
             if response == 'no':
                 return
+
+        # stop event loop
+        if ui.dbman.ro:  # do it now if DB is read only
             ui.exit()
+        else:  # trigger and wait for DB flush otherwise
+            await ui.apply_command(FlushCommand(callback=ui.exit))
+        ui.cleanup()
 
 
 @registerCommand(MODE, 'search', usage='search query', arguments=[
@@ -221,7 +225,7 @@ class ExternalCommand(Command):
             logging.debug('calling hook: touch_external_cmdlist')
             res = touchhook(cmd, shell=shell, spawn=spawn, thread=thread)
             logging.debug('got: %s', res)
-            cmd, shell, self.in_thread = res
+            cmd, shell, thread = res
         # otherwise if spawn requested and X11 is running
         elif spawn:
             if 'DISPLAY' in os.environ:
@@ -230,6 +234,7 @@ class ExternalCommand(Command):
                 termcmdlist = split_commandstring(term_cmd)
                 cmd = termcmdlist + cmd
             else:
+                logging.warning('unable to handle spawn outside of X11 without touch_external_cmdlist hook set')
                 thread = False
 
         self.cmdlist = cmd
@@ -257,6 +262,8 @@ class ExternalCommand(Command):
 
         logging.info('calling external command: %s', self.cmdlist)
 
+        err = None
+        proc = None
         ret = ''
         # TODO: these can probably be refactored in terms of helper.call_cmd
         # and helper.call_cmd_async
@@ -295,7 +302,7 @@ class ExternalCommand(Command):
                     ret = str(e)
                 else:
                     _, err = proc.communicate(stdin.read() if stdin else None)
-                if proc.returncode == 0:
+                if proc and proc.returncode == 0:
                     ret = 'success'
                 elif err:
                     ret = err.decode(urwid.util.detected_encoding)
@@ -305,7 +312,7 @@ class ExternalCommand(Command):
                 self.on_success()
         else:
             msg = "editor has exited with error code {} -- {}".format(
-                    proc.returncode,
+                    "None" if proc is None else proc.returncode,
                     ret or "No stderr output")
             ui.notify(msg, priority='error')
         if self.refocus and callerbuffer in ui.buffers:
@@ -869,7 +876,7 @@ class ComposeCommand(Command):
                     mimetype = helper.guess_mimetype(sigcontent)
                     if mimetype.startswith('text'):
                         sigcontent = helper.try_decode(sigcontent)
-                        self.envelope.body += '\n' + sigcontent
+                        self.envelope.body_txt += '\n' + sigcontent
             else:
                 ui.notify('could not locate signature: %s' % sig,
                           priority='error')
