@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2012  Patrick Totzke <patricktotzke@gmail.com>
+# Copyright (C) Patrick Totzke <patricktotzke@gmail.com>
 # Copyright © 2018 Dylan Baker
 # This file is released under the GNU GPL, version 3 or a later revision.
 # For further details see the COPYING file
@@ -39,6 +39,7 @@ from ..settings.const import settings
 from ..helper import parse_mailcap_nametemplate
 from ..helper import split_commandstring
 from ..utils import argparse as cargparse
+from ..utils import ansi
 from ..widgets.globals import AttachmentWidget
 
 MODE = 'thread'
@@ -149,11 +150,12 @@ class ReplyCommand(Command):
             quotestring = 'Quoting %s (%s)\n' % (name or address, timestamp)
         mailcontent = quotestring
         quotehook = settings.get_hook('text_quote')
+        body_text = ansi.remove_csi(self.message.get_body_text())
         if quotehook:
-            mailcontent += quotehook(self.message.get_body_text())
+            mailcontent += quotehook(body_text)
         else:
             quote_prefix = settings.get('quote_prefix')
-            for line in self.message.get_body_text().splitlines():
+            for line in body_text.splitlines():
                 mailcontent += quote_prefix + line + '\n'
 
         envelope = Envelope(bodytext=mailcontent, replied=self.message)
@@ -359,6 +361,10 @@ class ForwardCommand(Command):
                 subject = fsp + subject
         envelope.add('Subject', subject)
 
+        # Set forwarding reference headers
+        envelope.add('References', '<%s>' % self.message.get_message_id())
+        envelope.add('X-Forwarded-Message-Id', '<%s>' % self.message.get_message_id())
+
         # set From-header and sending account
         try:
             from_header, account = determine_sender(mail, 'reply')
