@@ -1,21 +1,16 @@
-# Copyright (C) 2015  Patrick Totzke <patricktotzke@gmail.com>
+# Copyright (C) Patrick Totzke <patricktotzke@gmail.com>
 # This file is released under the GNU GPL, version 3 or a later revision.
 # For further details see the COPYING file
-from __future__ import absolute_import
-
 import re
 import logging
 
-from twisted.internet.defer import inlineCallbacks, returnValue
-
 from ..errors import GPGProblem, GPGCode
 from ..settings.const import settings
 from ..settings.errors import NoMatchingAccount
 from .. import crypto
 
 
-@inlineCallbacks
-def set_encrypt(ui, envelope, block_error=False, signed_only=False):
+async def update_keys(ui, envelope, block_error=False, signed_only=False):
     """Find and set the encryption keys in an envolope.
 
     :param ui: the main user interface object
@@ -43,15 +38,18 @@ def set_encrypt(ui, envelope, block_error=False, signed_only=False):
             encrypt_keys.append(recipient)
 
     logging.debug("encryption keys: " + str(encrypt_keys))
-    keys = yield _get_keys(ui, encrypt_keys, block_error=block_error,
+    keys = await _get_keys(ui, encrypt_keys, block_error=block_error,
                            signed_only=signed_only)
     if keys:
-        envelope.encrypt_keys.update(keys)
+        envelope.encrypt_keys = keys
         envelope.encrypt = True
 
         if 'From' in envelope.headers:
             try:
-                acc = settings.get_account_by_address(envelope['From'])
+                if envelope.account is None:
+                    envelope.account = settings.account_matching_address(
+                        envelope['From'])
+                acc = envelope.account
                 if acc.encrypt_to_self:
                     if acc.gpg_key:
                         logging.debug('encrypt to self: %s', acc.gpg_key.fpr)
@@ -65,8 +63,7 @@ def set_encrypt(ui, envelope, block_error=False, signed_only=False):
         envelope.encrypt = False
 
 
-@inlineCallbacks
-def _get_keys(ui, encrypt_keyids, block_error=False, signed_only=False):
+async def _get_keys(ui, encrypt_keyids, block_error=False, signed_only=False):
     """Get several keys from the GPG keyring.  The keys are selected by keyid
     and are checked if they can be used for encryption.
 
@@ -95,9 +92,10 @@ def _get_keys(ui, encrypt_keyids, block_error=False, signed_only=False):
                 choices = {str(i): t for i, t in enumerate(tmp_choices, 1)}
                 keys_to_return = {str(i): t for i, t in enumerate([k for k in
                                   crypto.list_keys(hint=keyid)], 1)}
-                choosen_key = yield ui.choice("ambiguous keyid! Which " +
+                choosen_key = await ui.choice("ambiguous keyid! Which " +
                                               "key do you want to use?",
-                                              choices, keys_to_return)
+                                              choices=choices,
+                                              choices_to_return=keys_to_return)
                 if choosen_key:
                     keys[choosen_key.fpr] = choosen_key
                 continue
@@ -105,4 +103,4 @@ def _get_keys(ui, encrypt_keyids, block_error=False, signed_only=False):
                 ui.notify(str(e), priority='error', block=block_error)
                 continue
         keys[key.fpr] = key
-    returnValue(keys)
+    return keys
